@@ -15,6 +15,8 @@
 */
 
 /* this is not a core library module, so it doesn't define JPEG_INTERNALS */
+#include "config.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #ifdef HAVE_LIBJPEG
@@ -23,8 +25,8 @@
 #include "jpeg_memsrcdest.h"
 
 /* libjpeg8 and later come with their own (API compatible) memory source
-   and dest */
-#if JPEG_LIB_VERSION < 80
+   and dest, and older versions may have it backported */
+#if JPEG_LIB_VERSION < 80 && !defined(MEM_SRCDST_SUPPORTED)
 
 /* Expanded data source object for memory input */
 
@@ -211,15 +213,15 @@ init_destination (j_compress_ptr cinfo)
  * Empty the output buffer --- called whenever buffer fills up.
  *
  * In typical applications, this should write the entire output buffer
- * (ignoring the current state of next_output_byte & free_in_buffer), 
+ * (ignoring the current state of next_output_byte & free_in_buffer),
  * reset the pointer & count to the start of the buffer, and return TRUE
  * indicating that the buffer has been dumped.
  *
  * In applications that need to be able to suspend compression due to output
- * overrun, a FALSE return indicates that the buffer cannot be emptied now. 
+ * overrun, a FALSE return indicates that the buffer cannot be emptied now.
  * In this situation, the compressor will return to its caller (possibly with
- * an indication that it has not accepted all the supplied scanlines).  The  
- * application should resume compression after it has made more room in the  
+ * an indication that it has not accepted all the supplied scanlines).  The
+ * application should resume compression after it has made more room in the
  * output buffer.  Note that there are substantial restrictions on the use of
  * suspension --- see the documentation.
  *
@@ -247,7 +249,7 @@ empty_output_buffer (j_compress_ptr cinfo)
 }
 
 /*
- * Terminate destination --- called by jpeg_finish_compress   
+ * Terminate destination --- called by jpeg_finish_compress
  * after all data has been written.  Usually needs to flush buffer.
  *
  * NB: *not* called by jpeg_abort or jpeg_destroy; surrounding
