@@ -32,7 +32,7 @@ int digi_reset             		(GPPort *);
 int digi_init                          (GPPort *, CameraPrivateLibrary *);
 int digi_rewind (GPPort *port, CameraPrivateLibrary *priv);
 int digi_read_picture_data  (GPPort *, unsigned char *data,
-					    unsigned int size, int n);
+				unsigned int size, int n);
 
 /* Those functions don't need data transfer with the camera */
 int digi_get_num_frames                (CameraPrivateLibrary *, int entry);
@@ -40,8 +40,7 @@ unsigned int digi_get_comp_ratio      	     (CameraPrivateLibrary *, int entry);
 unsigned int digi_get_data_size             (CameraPrivateLibrary *, int entry);
 unsigned int digi_get_picture_width             (CameraPrivateLibrary *, int entry);
 int digi_is_clip                       (CameraPrivateLibrary *, int entry);
-int digi_decompress (unsigned char *out_data, unsigned char *data,
-							    int w, int h);
+int digi_decompress (unsigned char *out_data, unsigned char *data, int w, int h);
 int digi_postprocess	(int width, int height, unsigned char* rgb);
 int digi_delete_all	(GPPort *, CameraPrivateLibrary *priv);
 
