@@ -49,6 +49,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <time.h>
+#include <unistd.h>
 #include <errno.h>
 #include <sys/types.h>
 #ifdef HAVE_SYS_SELECT_H
@@ -61,6 +62,7 @@
 #else
 # include <sys/socket.h>
 # include <netinet/in.h>
+# include <arpa/inet.h>
 #endif
 #include "ptpip-private.h"
 
@@ -72,15 +74,11 @@
 
 #include "ptp.h"
 #include "ptp-private.h"
+#include "ptp-bugs.h"
 
 #define PTPIP_VERSION_MAJOR 0x0001
 #define PTPIP_VERSION_MINOR 0x0000
 
-#include "ptp.h"
-#include "ptp-bugs.h"
-
-#include "ptp-pack.c"
-
 #define fujiptpip_len		0
 #define fujiptpip_type		4	/* not always present */
 
