@@ -1,13 +1,13 @@
 /* compile with gcc -Wall -o canon-capture -lgphoto2 canon-capture.c
  * This code released into the public domain 21 July 2008
- * 
+ *
  * This program does the equivalent of:
  * gphoto2 --shell
  *   > set-config capture=1
  *   > capture-image-and-download
  * compile with gcc -Wall -o canon-capture -lgphoto2 canon-capture.c
  *
- * Taken from: http://credentiality2.blogspot.com/2008/07/linux-libgphoto2-image-capture-from.html 
+ * Taken from: http://credentiality2.blogspot.com/2008/07/linux-libgphoto2-image-capture-from.html
  */
 
 #include <stdlib.h>
@@ -21,9 +21,9 @@
 
 #include "samples.h"
 
-static void errordumper(GPLogLevel level, const char *domain, const char *str,
-                 void *data) {
-  printf("%s (data %p)\n", str,data);
+static void errordumper(GPLogLevel level, const char *domain, const char *str, void *data)
+{
+	printf("%s (data %p)\n", str,data);
 }
 
 /* This seems to have no effect on where images go
@@ -100,7 +100,7 @@ capture_to_file(Camera *canon, GPContext *canoncontext, char *fn) {
 
 	printf("Pathname on the camera: %s/%s\n", camera_file_path.folder, camera_file_path.name);
 
-	fd = open(fn, O_CREAT | O_WRONLY, 0644);
+	fd = open(fn, O_CREAT | O_WRONLY | O_BINARY, 0644);
 	retval = gp_file_new_from_fd(&canonfile, fd);
 	printf("  Retval: %d\n", retval);
 	retval = gp_camera_file_get(canon, camera_file_path.folder, camera_file_path.name,
@@ -186,7 +186,7 @@ main(int argc, char **argv) {
 		gp_file_unref(file);
 	/*
 		sprintf(output_file, "image-%03d.jpg", i);
-	        capture_to_file(canon, canoncontext, output_file);
+		capture_to_file(canon, canoncontext, output_file);
 	*/
 	}
 	retval = camera_eosviewfinder(canon,canoncontext,0);
