@@ -27,6 +27,7 @@
 #define _POSIX_SOURCE
 #define _DEFAULT_SOURCE
 #define _DARWIN_C_SOURCE
+#define _XOPEN_SOURCE 500
 
 #include "config.h"
 #include <gphoto2/gphoto2-file.h>
@@ -46,7 +47,7 @@
 
 #define CHECK_RESULT(result) {int r = (result); if (r < 0) return (r);}
 
-/* lengt of one path component */
+/* length of one path component */
 #ifndef MAX_PATH
 # define MAX_PATH 256
 #endif
@@ -55,17 +56,17 @@
  * \internal
  */
 struct _CameraFile {
-        char		mime_type [64];
-        char		name [MAX_PATH];
-        int		ref_count;
-        time_t		mtime;
+	char		mime_type [64];
+	char		name [MAX_PATH];
+	int		ref_count;
+	time_t		mtime;
 
 	CameraFileAccessType	accesstype;
 
 	/* for GP_FILE_ACCESSTYPE_MEMORY files */
-        unsigned long	size;
-        unsigned char	*data;
-        unsigned long	offset;	/* read pointer */
+	unsigned long	size;
+	unsigned char	*data;
+	unsigned long	offset;	/* read pointer */
 
 	/* for GP_FILE_ACCESSTYPE_FD files */
 	int		fd;
@@ -241,7 +242,7 @@ gp_file_append (CameraFile *file, const char *data,
 		GP_LOG_E ("Unknown file access type %d", file->accesstype);
 		return GP_ERROR;
 	}
-        return (GP_OK);
+	return (GP_OK);
 }
 
 /**
@@ -299,7 +300,7 @@ gp_file_slurp (CameraFile *file, char *data,
 		GP_LOG_E ("Unknown file access type %d", file->accesstype);
 		return GP_ERROR;
 	}
-        return (GP_OK);
+	return (GP_OK);
 }
 
 
@@ -575,26 +576,30 @@ gp_file_save (CameraFile *file, const char *filename)
  * See also the GP_MIME_* definitions.
  */
 static const char *mime_table[] = {
-    "bmp",  GP_MIME_BMP,
-    "jpg",  GP_MIME_JPEG,
-    "tif",  GP_MIME_TIFF,
-    "ppm",  GP_MIME_PPM,
-    "pgm",  GP_MIME_PGM,
-    "pnm",  GP_MIME_PNM,
-    "png",  GP_MIME_PNG,
-    "wav",  GP_MIME_WAV,
-    "avi",  GP_MIME_AVI,
-    "mp3",  GP_MIME_MP3,
-    "wma",  GP_MIME_WMA,
-    "asf",  GP_MIME_ASF,
-    "ogg",  GP_MIME_OGG,
-    "mpg",  GP_MIME_MPEG,
-    "raw",  GP_MIME_RAW,
-    "mts",  GP_MIME_AVCHD,
-    "m2ts", GP_MIME_AVCHD,
-    "arw",  GP_MIME_ARW,
-    "txt",  GP_MIME_TXT,
-    NULL};
+	"bmp",  GP_MIME_BMP,
+	"jpg",  GP_MIME_JPEG,
+	"tif",  GP_MIME_TIFF,
+	"ppm",  GP_MIME_PPM,
+	"pgm",  GP_MIME_PGM,
+	"pnm",  GP_MIME_PNM,
+	"png",  GP_MIME_PNG,
+	"wav",  GP_MIME_WAV,
+	"avi",  GP_MIME_AVI,
+	"mp3",  GP_MIME_MP3,
+	"wma",  GP_MIME_WMA,
+	"asf",  GP_MIME_ASF,
+	"ogg",  GP_MIME_OGG,
+	"mpg",  GP_MIME_MPEG,
+	"raw",  GP_MIME_RAW,
+	"mts",  GP_MIME_AVCHD,
+	"m2ts", GP_MIME_AVCHD,
+	"arw",  GP_MIME_ARW,
+	"raf",  GP_MIME_RAF,
+	"txt",  GP_MIME_TXT,
+	"qtk",  GP_MIME_QTKT,
+	"qtk",  GP_MIME_QTKN,
+	NULL
+};
 /**
  * @param file a #CameraFile
  * @param filename
@@ -604,10 +609,10 @@ static const char *mime_table[] = {
 int
 gp_file_open (CameraFile *file, const char *filename)
 {
-        FILE *fp;
-        char *name, *dot;
-        long size, size_read;
-        int  i;
+	FILE *fp;
+	char *name, *dot;
+	long size, size_read;
+	int  i;
 	struct stat s;
 
 
@@ -615,12 +620,12 @@ gp_file_open (CameraFile *file, const char *filename)
 
 	CHECK_RESULT (gp_file_clean (file));
 
-        fp = fopen(filename, "r");
-        if (!fp)
+	fp = fopen(filename, "r");
+	if (!fp)
 		return (GP_ERROR);
 	fseek (fp, 0, SEEK_END);
-        size = ftell (fp);
-        rewind (fp);
+	size = ftell (fp);
+	rewind (fp);
 
 	switch (file->accesstype) {
 	case GP_FILE_ACCESSTYPE_MEMORY:
@@ -653,34 +658,35 @@ gp_file_open (CameraFile *file, const char *filename)
 		break;
 	}
 
-        name = strrchr (filename, '/');
-        if (name)
-                strncpy (file->name, name + 1, sizeof (file->name));
-           else
-                strncpy (file->name, filename, sizeof (file->name));
+	name = strrchr (filename, '/');
+	if (name)
+		strncpy (file->name, name + 1, sizeof (file->name));
+	else
+		strncpy (file->name, filename, sizeof (file->name));
 
-        /* MIME lookup */
-        dot = strrchr (filename, '.');
-        if (dot) {
-            for (i = 0; mime_table[i] ; i+=2)
-                if (!strcasecmp (mime_table[i], dot+1)) {
-                    strncpy (file->mime_type, mime_table[i+1], sizeof(file->mime_type));
-                    break;
-                }
-            if (!mime_table[i])
-                /*
-                 * We did not found the type in the lookup table,
-                 * so we use the file suffix as mime type.
-                 * Note: This should probably use GP_MIME_UNKNOWN instead
-                 * of returning a non-standard type.
-                 */
-                sprintf(file->mime_type, "image/%s", dot + 1);
-        } else
-            /*
-             * Damn, no filename suffix...
-             */
-            strncpy (file->mime_type, GP_MIME_UNKNOWN,
-		     sizeof (file->mime_type));
+	/* MIME lookup */
+	dot = strrchr (filename, '.');
+	if (dot) {
+		for (i = 0; mime_table[i] ; i+=2)
+			if (!strcasecmp (mime_table[i], dot+1)) {
+				strncpy (file->mime_type, mime_table[i+1], sizeof(file->mime_type));
+				break;
+			}
+		if (!mime_table[i])
+			/*
+			* We did not found the type in the lookup table,
+			* so we use the file suffix as mime type.
+			* Note: This should probably use GP_MIME_UNKNOWN instead
+			* of returning a non-standard type.
+			*/
+			sprintf(file->mime_type, "image/%s", dot + 1);
+	} else {
+		/*
+		* Damn, no filename suffix...
+		*/
+		strncpy (file->mime_type, GP_MIME_UNKNOWN,
+			sizeof (file->mime_type));
+	}
 
 	if (stat (filename, &s) != -1) {
 		file->mtime = s.st_mtime;
@@ -688,7 +694,7 @@ gp_file_open (CameraFile *file, const char *filename)
 		file->mtime = time (NULL);
 	}
 
-        return (GP_OK);
+	return (GP_OK);
 }
 
 
@@ -700,10 +706,10 @@ gp_file_open (CameraFile *file, const char *filename)
 int
 gp_file_clean (CameraFile *file)
 {
-        /*
+	/*
 	 * Frees a CameraFile's components, not the CameraFile itself.
 	 * This is used to prep a CameraFile struct to be filled.
-         */
+	 */
 
 	C_PARAMS (file);
 
@@ -718,7 +724,7 @@ gp_file_clean (CameraFile *file)
 	default:break;
 	}
 	strcpy (file->name, "");
-        return (GP_OK);
+	return (GP_OK);
 }
 
 /**
@@ -1031,7 +1037,7 @@ int
 gp_file_detect_mime_type (CameraFile *file)
 {
 	const char TIFF_SOI_MARKER[] = {(char) 0x49, (char) 0x49, (char) 0x2A,
-				        (char) 0x00, (char) 0x08, '\0' };
+					(char) 0x00, (char) 0x08, '\0' };
 	const char JPEG_SOI_MARKER[] = {(char) 0xFF, (char) 0xD8, '\0' };
 
 	C_PARAMS (file);
@@ -1089,6 +1095,10 @@ gp_file_adjust_name_for_mime_type (CameraFile *file)
 	const char *table[] = {
 		GP_MIME_RAW,  "raw",
 		GP_MIME_JPEG, "jpg",
+		GP_MIME_NEF,  "nef",
+		GP_MIME_CRW,  "crw",
+		GP_MIME_CR2,  "cr2",
+		GP_MIME_CR3,  "cr3",
 		GP_MIME_PNG,  "png",
 		GP_MIME_PPM,  "ppm",
 		GP_MIME_PGM,  "pgm",
@@ -1097,19 +1107,18 @@ gp_file_adjust_name_for_mime_type (CameraFile *file)
 		GP_MIME_WAV,  "wav",
 		GP_MIME_BMP,  "bmp",
 		GP_MIME_AVI,  "avi",
-		GP_MIME_CRW,  "crw",
-		GP_MIME_CR2,  "cr2",
-		GP_MIME_CR3,  "cr3",
 		GP_MIME_ARW,  "arw",
-		GP_MIME_NEF,  "nef",
+		GP_MIME_RAF,  "raf",
 		GP_MIME_TXT,  "txt",
+		GP_MIME_QTKT, "qtk",
+		GP_MIME_QTKN, "qtk",
 		NULL};
 
 	C_PARAMS (file);
 
 	GP_LOG_D ("Adjusting file name for mime type '%s'...", file->mime_type);
 	for (x = 0; table[x]; x += 2)
-                if (!strcmp (file->mime_type, table[x])) {
+		if (!strcmp (file->mime_type, table[x])) {
 
 			/* Search the current suffix and erase it */
 			suffix = strrchr (file->name, '.');
