@@ -54,8 +54,9 @@ var NAVTREEINDEX =
 "__stdint_8h_source.html",
 "gphoto2-endian_8h_source.html",
 "gphoto2-port-info-list_8h.html#ab60c983825bfa2b6aa2fcb1e1a32b08f",
-"gphoto2-widget_8h.html#a7148abb7985c2d5d6310ef6b25d38256"
+"gphoto2-widget_8h.html#a3017f318e2dadaf82d5d55140594bcdf"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
+var LISTOFALLMEMBERS = 'List of all members';
\ No newline at end of file
