@@ -81,27 +81,29 @@ var NAVTREEINDEX2 =
 "gphoto2-port-version_8h_source.html":[3,0,3,0,6],
 "gphoto2-port_8c.html":[3,0,3,1,8],
 "gphoto2-port_8c.html#a0077bb0c6918d27e5a36f27087e2c277":[3,0,3,1,8,2],
-"gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897":[3,0,3,1,8,37],
-"gphoto2-port_8c.html#a0cbdaa571a0eef7441fee91a244e21f2":[3,0,3,1,8,31],
+"gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897":[3,0,3,1,8,39],
+"gphoto2-port_8c.html#a0cbdaa571a0eef7441fee91a244e21f2":[3,0,3,1,8,32],
 "gphoto2-port_8c.html#a0d9ec033ed72d9fb9e29bfd8d4010c44":[3,0,3,1,8,15],
-"gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d":[3,0,3,1,8,36],
+"gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d":[3,0,3,1,8,37],
 "gphoto2-port_8c.html#a247bb45fcf90021f45ae137df40dd47a":[3,0,3,1,8,8],
-"gphoto2-port_8c.html#a283ebf127e608cc77b137103bbde3caf":[3,0,3,1,8,32],
+"gphoto2-port_8c.html#a283ebf127e608cc77b137103bbde3caf":[3,0,3,1,8,33],
 "gphoto2-port_8c.html#a2ae81836b1bca7ae97695d754cc9a3a6":[3,0,3,1,8,11],
-"gphoto2-port_8c.html#a2e5d3e6f918acb16e8ee6996018507a6":[3,0,3,1,8,35],
+"gphoto2-port_8c.html#a2e5d3e6f918acb16e8ee6996018507a6":[3,0,3,1,8,36],
+"gphoto2-port_8c.html#a37282580befede26136589451b6b7712":[3,0,3,1,8,38],
 "gphoto2-port_8c.html#a4389daae7f57c7759775ad1dd512c70a":[3,0,3,1,8,25],
 "gphoto2-port_8c.html#a4a192eaac78b326ebe41e8e4441a38e4":[3,0,3,1,8,20],
-"gphoto2-port_8c.html#a4fbc4a2c1583e25d5e220b757375f305":[3,0,3,1,8,34],
+"gphoto2-port_8c.html#a4fbc4a2c1583e25d5e220b757375f305":[3,0,3,1,8,35],
 "gphoto2-port_8c.html#a56b83abbf58d7b01bdfd568bc3fff917":[3,0,3,1,8,18],
 "gphoto2-port_8c.html#a5d67338933ddaed39c4fb20a23d76ec2":[3,0,3,1,8,30],
 "gphoto2-port_8c.html#a68fb24a4f729ec5be85f4aedf3bb8e4f":[3,0,3,1,8,23],
+"gphoto2-port_8c.html#a71ca78b45cc30a9f2ef4b521c74dc864":[3,0,3,1,8,31],
 "gphoto2-port_8c.html#a78fda26011604ff372d9a1a7ff83bc62":[3,0,3,1,8,9],
 "gphoto2-port_8c.html#a790fff9ba13a8b2730cdc1213ec98d48":[3,0,3,1,8,29],
 "gphoto2-port_8c.html#a7a8d75aa016e04b9c0d3b7849681ebe5":[3,0,3,1,8,12],
 "gphoto2-port_8c.html#a8f66d05b6a22677ef689180eacb2f85d":[3,0,3,1,8,14],
 "gphoto2-port_8c.html#a8fd66df2fcf8598f1765f429d746284e":[3,0,3,1,8,7],
 "gphoto2-port_8c.html#a926276a279193a52013da9e05399ec29":[3,0,3,1,8,24],
-"gphoto2-port_8c.html#a946715a386d9280d71b4ec58488aabd4":[3,0,3,1,8,33],
+"gphoto2-port_8c.html#a946715a386d9280d71b4ec58488aabd4":[3,0,3,1,8,34],
 "gphoto2-port_8c.html#a9503a6f8c4d87a2c22b802ce099cf8ef":[3,0,3,1,8,22],
 "gphoto2-port_8c.html#a976f2b7d7c2bd3f5399a6f5829044957":[3,0,3,1,8,13],
 "gphoto2-port_8c.html#a99a4671624d0b4d5f86cb5aaf94941fb":[3,0,3,1,8,19],
@@ -123,19 +125,20 @@ var NAVTREEINDEX2 =
 "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fba011c902e5923e373cf1a36de818c4886":[3,0,3,0,7,21,2],
 "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fba6817c46c2ee6caea47b010305d6640ca":[3,0,3,0,7,21,1],
 "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fbadea6c7888c5b3d31fc58a97400003e4a":[3,0,3,0,7,21,0],
-"gphoto2-port_8h.html#a08cc8e20df73217baeafccbc71ba9897":[3,0,3,0,7,53],
-"gphoto2-port_8h.html#a0cbdaa571a0eef7441fee91a244e21f2":[3,0,3,0,7,47],
+"gphoto2-port_8h.html#a08cc8e20df73217baeafccbc71ba9897":[3,0,3,0,7,55],
+"gphoto2-port_8h.html#a0cbdaa571a0eef7441fee91a244e21f2":[3,0,3,0,7,48],
 "gphoto2-port_8h.html#a0d9ec033ed72d9fb9e29bfd8d4010c44":[3,0,3,0,7,35],
-"gphoto2-port_8h.html#a1118c50abbdf1926d6e08e0b6bb1209d":[3,0,3,0,7,52],
+"gphoto2-port_8h.html#a1118c50abbdf1926d6e08e0b6bb1209d":[3,0,3,0,7,53],
 "gphoto2-port_8h.html#a247bb45fcf90021f45ae137df40dd47a":[3,0,3,0,7,28],
-"gphoto2-port_8h.html#a283ebf127e608cc77b137103bbde3caf":[3,0,3,0,7,48],
+"gphoto2-port_8h.html#a283ebf127e608cc77b137103bbde3caf":[3,0,3,0,7,49],
 "gphoto2-port_8h.html#a2ae81836b1bca7ae97695d754cc9a3a6":[3,0,3,0,7,31],
-"gphoto2-port_8h.html#a2e5d3e6f918acb16e8ee6996018507a6":[3,0,3,0,7,51],
+"gphoto2-port_8h.html#a2e5d3e6f918acb16e8ee6996018507a6":[3,0,3,0,7,52],
+"gphoto2-port_8h.html#a37282580befede26136589451b6b7712":[3,0,3,0,7,54],
 "gphoto2-port_8h.html#a42b49c0d94d2411a10e73b6b2614add7":[3,0,3,0,7,9],
 "gphoto2-port_8h.html#a47331c65bcadc27c28c990970be8f283":[3,0,3,0,7,6],
 "gphoto2-port_8h.html#a4a192eaac78b326ebe41e8e4441a38e4":[3,0,3,0,7,40],
 "gphoto2-port_8h.html#a4d674142b3150343bd4f10ef5064a772":[3,0,3,0,7,14],
-"gphoto2-port_8h.html#a4fbc4a2c1583e25d5e220b757375f305":[3,0,3,0,7,50],
+"gphoto2-port_8h.html#a4fbc4a2c1583e25d5e220b757375f305":[3,0,3,0,7,51],
 "gphoto2-port_8h.html#a56b83abbf58d7b01bdfd568bc3fff917":[3,0,3,0,7,38],
 "gphoto2-port_8h.html#a5d67338933ddaed39c4fb20a23d76ec2":[3,0,3,0,7,46],
 "gphoto2-port_8h.html#a68fb24a4f729ec5be85f4aedf3bb8e4f":[3,0,3,0,7,43],
@@ -146,7 +149,7 @@ var NAVTREEINDEX2 =
 "gphoto2-port_8h.html#a8c998a9cd2ee04473f1a3d5ff5597a05":[3,0,3,0,7,16],
 "gphoto2-port_8h.html#a8f66d05b6a22677ef689180eacb2f85d":[3,0,3,0,7,34],
 "gphoto2-port_8h.html#a8fd66df2fcf8598f1765f429d746284e":[3,0,3,0,7,27],
-"gphoto2-port_8h.html#a946715a386d9280d71b4ec58488aabd4":[3,0,3,0,7,49],
+"gphoto2-port_8h.html#a946715a386d9280d71b4ec58488aabd4":[3,0,3,0,7,50],
 "gphoto2-port_8h.html#a94aef01d47cdb21a645475901751a92a":[3,0,3,0,7,19],
 "gphoto2-port_8h.html#a94aef01d47cdb21a645475901751a92aa36b93ac460c36ca2d335310dde15d2c3":[3,0,3,0,7,19,1],
 "gphoto2-port_8h.html#a94aef01d47cdb21a645475901751a92aad4b56e3690d434160baac2d4236454a6":[3,0,3,0,7,19,0],
@@ -155,6 +158,7 @@ var NAVTREEINDEX2 =
 "gphoto2-port_8h.html#a99a4671624d0b4d5f86cb5aaf94941fb":[3,0,3,0,7,39],
 "gphoto2-port_8h.html#a9c0f2b387776709091a7e7a41f98098b":[3,0,3,0,7,15],
 "gphoto2-port_8h.html#aa165d3c4720ac15bab9d0fc4f318aa92":[3,0,3,0,7,13],
+"gphoto2-port_8h.html#aa331cc379e69f0183faa6dd7af0f8c05":[3,0,3,0,7,47],
 "gphoto2-port_8h.html#aa3ac8ac353d96106575bf951f997276c":[3,0,3,0,7,23],
 "gphoto2-port_8h.html#aa5c3be2ad2546c829dc21d4d8fabb08d":[3,0,3,0,7,37],
 "gphoto2-port_8h.html#aa94b9e7933d1f0e5fc540660c25aa7c8":[3,0,3,0,7,20],
@@ -196,10 +200,14 @@ var NAVTREEINDEX2 =
 "gphoto2-result_8h.html#ade2d19223246e133a72869939d103a98":[3,0,1,7,3],
 "gphoto2-result_8h_source.html":[3,0,1,7],
 "gphoto2-setting_8c.html":[3,0,2,18],
+"gphoto2-setting_8c.html#a1e9f5bf328f023f7d27e6a12743a4684":[3,0,2,18,4],
 "gphoto2-setting_8c.html#a4b50249c04f6a48156bad839827e67b7":[3,0,2,18,1],
+"gphoto2-setting_8c.html#a5511bf5b76f05f019749934bf598bf84":[3,0,2,18,3],
 "gphoto2-setting_8c.html#a6100f1cf5f3e90c2491807b6db1796af":[3,0,2,18,2],
 "gphoto2-setting_8h.html":[3,0,1,8],
+"gphoto2-setting_8h.html#a1e9f5bf328f023f7d27e6a12743a4684":[3,0,1,8,3],
 "gphoto2-setting_8h.html#a4b50249c04f6a48156bad839827e67b7":[3,0,1,8,0],
+"gphoto2-setting_8h.html#a5511bf5b76f05f019749934bf598bf84":[3,0,1,8,2],
 "gphoto2-setting_8h.html#a6100f1cf5f3e90c2491807b6db1796af":[3,0,1,8,1],
 "gphoto2-setting_8h_source.html":[3,0,1,8],
 "gphoto2-version_8c.html":[3,0,2,19],
@@ -241,13 +249,5 @@ var NAVTREEINDEX2 =
 "gphoto2-widget_8h.html#a01706284163682eb459b045b651a2fcf":[3,0,1,10,19],
 "gphoto2-widget_8h.html#a160a340c58e006a1a4de0ac77e02e136":[3,0,1,10,17],
 "gphoto2-widget_8h.html#a20783a5aec3e3a7cd4c8ce3af7a92361":[3,0,1,10,18],
-"gphoto2-widget_8h.html#a23365c0fe61546fc655765636340836d":[3,0,1,10,1],
-"gphoto2-widget_8h.html#a3017f318e2dadaf82d5d55140594bcdf":[3,0,1,10,11],
-"gphoto2-widget_8h.html#a467afee62da7ca075c8b24c71cfd812a":[3,0,1,10,9],
-"gphoto2-widget_8h.html#a4c4ea20c4d069c418399754822644174":[3,0,1,10,27],
-"gphoto2-widget_8h.html#a582ecd400d10bb040b35c317c48cf638":[3,0,1,10,29],
-"gphoto2-widget_8h.html#a58d57830ff9a7ce66b1b4b9faa93948a":[3,0,1,10,31],
-"gphoto2-widget_8h.html#a5b80fa207622d0efc676c3219c6150eb":[3,0,1,10,25],
-"gphoto2-widget_8h.html#a677590f6805dbf542d84cfe5a2718789":[3,0,1,10,33],
-"gphoto2-widget_8h.html#a6e6287e13a841e6f7631d06d72c06237":[3,0,1,10,32]
+"gphoto2-widget_8h.html#a23365c0fe61546fc655765636340836d":[3,0,1,10,1]
 };
